@@ -16,10 +16,11 @@ MSG_LOGIN_ABORTED = '\nLogin aborted. Bye.'
 MSG_EXIT = '\nBye.'
 MSG_SESSION_TIMEOUT = 'Session timed out. Please login again.'
 PROMPT = 'RCON {host}:{port}> '
+VALID_PORTS = range(0, 65536)
 
 
 def read_host() -> str:
-    """Reads the host."""
+    """Read the host."""
 
     while True:
         try:
@@ -30,7 +31,7 @@ def read_host() -> str:
 
 
 def read_port() -> int:
-    """Reads the port."""
+    """Read the port."""
 
     while True:
         try:
@@ -45,14 +46,14 @@ def read_port() -> int:
             print(f'Invalid integer: {port}')
             continue
 
-        if 0 <= port <= 65535:
+        if port in VALID_PORTS:
             return port
 
         print(f'Invalid port: {port}')
 
 
 def read_passwd() -> str:
-    """Reads the password."""
+    """Read the password."""
 
     while True:
         try:
@@ -62,7 +63,7 @@ def read_passwd() -> str:
 
 
 def get_config(host: str, port: int, passwd: str) -> Config:
-    """Reads the necessary arguments."""
+    """Read the necessary arguments."""
 
     if host is None:
         host = read_host()
@@ -77,7 +78,7 @@ def get_config(host: str, port: int, passwd: str) -> Config:
 
 
 def login(client: BaseClient, passwd: str) -> str:
-    """Performs a login."""
+    """Perform a login."""
 
     while True:
         try:
@@ -91,7 +92,7 @@ def login(client: BaseClient, passwd: str) -> str:
 
 
 def process_input(client: BaseClient, passwd: str, prompt: str) -> bool:
-    """Processes the CLI input."""
+    """Process the CLI input."""
 
     try:
         command = input(prompt)
@@ -130,10 +131,14 @@ def process_input(client: BaseClient, passwd: str, prompt: str) -> bool:
 
 
 def rconcmd(
-        client_cls: Type[BaseClient], host: str, port: int, passwd: str, *,
+        client_cls: Type[BaseClient],
+        host: str,
+        port: int,
+        passwd: str,
+        *,
         prompt: str = PROMPT
 ):
-    """Initializes the console."""
+    """Initialize the console."""
 
     try:
         host, port, passwd = get_config(host, port, passwd)
